OptimusMewsLogo class
Mews Logo component with clearly defined margins, size and color options.
It is provided for better consistency across all products. No text or visual elements may be placed within 1x(x = logo heigh) of the space around it.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- OptimusMewsLogo
Constructors
- OptimusMewsLogo({Key? key, OptimusMewsLogoVariant logoVariant = OptimusMewsLogoVariant.logomark, OptimusMewsLogoSizeVariant sizeVariant = OptimusMewsLogoSizeVariant.medium, OptimusMewsLogoColorVariant? colorVariant, OptimusMewsLogoAlignVariant alignVariant = OptimusMewsLogoAlignVariant.topCenter, String? semanticsLabel, String? productName, bool useMargin = true})
-
const
Properties
- alignVariant → OptimusMewsLogoAlignVariant
-
The alignment of the logo.
final
- colorVariant → OptimusMewsLogoColorVariant?
-
The color variant of the logo. If null, will use an appropriate color
based on the system color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- logoVariant → OptimusMewsLogoVariant
-
The variant of the logo to be displayed.
final
- productName → String?
-
The name of the product to be displayed next to the logo.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
The semantics label for the logo. Defaults to the 'Mews Logo'.
We suggest using a localized string for better accessibility.
final
- sizeVariant → OptimusMewsLogoSizeVariant
-
The size of the logo to be displayed.
final
- useMargin → bool
-
Whether to use margin around the logo.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited